@@ -14,6 +14,12 @@ class Mock(object):
         self.__dict__.update(kw)
 
 
+class MockDict(Mock):
+
+    def __getitem__(self, k):
+        return getattr(self, k)
+
+
 _tracker = fileio.TempTracker()
 gen_tempfile = _tracker.gen_tempfile
 gen_tempdir = _tracker.gen_tempdir
